==> ogre-next-2.2.4-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_g_l3_plus_vao_manager.js <==
var class_ogre_1_1_g_l3_plus_vao_manager =
[
    [ "Block", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_block.html", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_block" ],
    [ "StrideChanger", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_stride_changer.html", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_stride_changer" ],
    [ "BlockVec", "class_ogre_1_1_g_l3_plus_vao_manager.html#acf63571a368c427ffdcfb1897ec5f041", null ],
    [ "MemoryStatsEntryVec", "class_ogre_1_1_g_l3_plus_vao_manager.html#a8a984ae987b00e95b35198131a4e9a6b", null ],
    [ "StrideChangerVec", "class_ogre_1_1_g_l3_plus_vao_manager.html#a79c5a9e410625780fcc610f3243be960", null ],
    [ "GL3PlusVaoManager", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4ceaf6e928e2079f263dab39e7d8d6a6", null ],
    [ "~GL3PlusVaoManager", "class_ogre_1_1_g_l3_plus_vao_manager.html#add095b8663546d8520f8cc9c0d92c90c", null ],
    [ "_beginFrame", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad255ed9aad893f120f6a29e172052ccd", null ],
    [ "_getDynamicBufferCurrentFrameNoWait", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4c2c223f495c035085ffa2b7323bce82", null ],
    [ "_notifyStagingBufferEnteredZeroRef", "class_ogre_1_1_g_l3_plus_vao_manager.html#a374058250675bac30bfb5b03c26b5eb7", null ],
    [ "_notifyStagingBufferLeftZeroRef", "class_ogre_1_1_g_l3_plus_vao_manager.html#ace2545e4ce03ff536e3d505e4669cc91", null ],
    [ "_update", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6a803fbce3bc62ad1bc5a0632bf69da7", null ],
    [ "bindDrawId", "class_ogre_1_1_g_l3_plus_vao_manager.html#ae7f85d710473526ee0985c4def94dcb5", null ],
    [ "calculateVertexSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#a222d4e40df5eb53ab0b050e37aca7b89", null ],
    [ "cleanupEmptyPools", "class_ogre_1_1_g_l3_plus_vao_manager.html#acfe2479c58ace6ff748d17cc0f65091d", null ],
    [ "createAsyncTicket", "class_ogre_1_1_g_l3_plus_vao_manager.html#a530db71d0308ab9ad62b1243be3196ff", null ],
    [ "createConstBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a952ab60d93451fc2ea18e14bbc31c309", null ],
    [ "createIndexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a0f791867304e682175612237b3bfd470", null ],
    [ "createIndirectBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad5ec74188530974bc3c28f3d1ab2982f", null ],
    [ "createMultiSourceVertexBufferPool", "class_ogre_1_1_g_l3_plus_vao_manager.html#a167879924fcc223de12f276c61be0c88", null ],
    [ "createStagingBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4e8851d90bc61865477947731455440b", null ],
    [ "createStagingTexture", "class_ogre_1_1_g_l3_plus_vao_manager.html#afe72cf8783a9d2438c978550a68366f5", null ],
    [ "createTexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a15deceadb9ee88de12fd801464e4b09b", null ],
    [ "createUavBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6001313fdecc1491daa683595fdb5018", null ],
    [ "createVertexArrayObject", "class_ogre_1_1_g_l3_plus_vao_manager.html#a76927e1aaf3cdd9dfddcf4f7bbb0a48a", null ],
    [ "createVertexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a163fd24c8a7f2c33595bb7fe94e97cf3", null ],
    [ "destroyConstBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a51f5147151805c3d294ae200683d76bb", null ],
    [ "destroyIndexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a04c53b84b4c6ba27fdcbf57a08d4b044", null ],
    [ "destroyIndirectBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4e7e88128e2496523ab0ca8e35634879", null ],
    [ "destroyStagingTexture", "class_ogre_1_1_g_l3_plus_vao_manager.html#aa79c19ee474881cbf8f49600395c27ca", null ],
    [ "destroyTexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6241229a8f3c895dcd49e7d0e8dfe545", null ],
    [ "destroyUavBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a0f235ad527a20a7c20b9daae8dc18ff7", null ],
    [ "destroyVertexArrayObject", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4d56b87f51c489bdc2df07d1ce040512", null ],
    [ "destroyVertexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a1dce3c8cb8c7d08ff77e6c4776fed1f4", null ],
    [ "getAttributeIndexFor", "class_ogre_1_1_g_l3_plus_vao_manager.html#a2cdfac5014aab294b0c75ae452919bbd", null ],
    [ "getConstBufferAlignment", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4a00e866aebffe5114767ce1fc81bea8", null ],
    [ "getConstBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6613f84365a386b9a50fed61a96cfc7a", null ],
    [ "getDefaultStagingBufferLifetime", "class_ogre_1_1_g_l3_plus_vao_manager.html#adb22409286339939dc6d49e44a8f3683", null ],
    [ "getDefaultStagingBufferUnfencedTime", "class_ogre_1_1_g_l3_plus_vao_manager.html#a5388b5890025a724a42f4469363bb267", null ],
    [ "getDynamicBufferMultiplier", "class_ogre_1_1_g_l3_plus_vao_manager.html#a9b609165fb053afe550711546254e230", null ],
    [ "getFrameCount", "class_ogre_1_1_g_l3_plus_vao_manager.html#ab528ecee92f02772be5dc8329c0e1e1b", null ],
    [ "getMaxVertexAttribs", "class_ogre_1_1_g_l3_plus_vao_manager.html#a5140b54e5640aa8b8b931a6c14d1e4c2", null ],
    [ "getMemoryStats", "class_ogre_1_1_g_l3_plus_vao_manager.html#a70811386532e1aa7ad5600165a4013a6", null ],
    [ "getStagingBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a755b7f61f17c568f32a6708c4d4cb986", null ],
    [ "getTexBufferAlignment", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6c4856f0420c296824372ce64825cbfd", null ],
    [ "getTexBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#a2d0feae113e7a1003d76b3640c51d243", null ],
    [ "getTimer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a68920b89d7ab929fc78d2013ef419bbe", null ],
    [ "getUavBufferAlignment", "class_ogre_1_1_g_l3_plus_vao_manager.html#a50170e8b31bd91edd07b36c3fb6678f7", null ],
    [ "getUavBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#ae94298022c4ca57ca88a9440c223af4c", null ],
    [ "isFrameFinished", "class_ogre_1_1_g_l3_plus_vao_manager.html#a82ef161fc8e37d2217cd10c849005a16", null ],
    [ "mergeContiguousBlocks", "class_ogre_1_1_g_l3_plus_vao_manager.html#addb5d4187c15479363e1cf47a7b21844", null ],
    [ "operator delete", "class_ogre_1_1_g_l3_plus_vao_manager.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_g_l3_plus_vao_manager.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_g_l3_plus_vao_manager.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_g_l3_plus_vao_manager.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
    [ "operator new", "class_ogre_1_1_g_l3_plus_vao_manager.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
    [ "operator new", "class_ogre_1_1_g_l3_plus_vao_manager.html#ab78a921e54419be677839cdf15d1f0b8", null ],
    [ "operator new[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#afa2943846ba6a2b5824a12857139cf5e", null ],
    [ "operator new[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4be37baef81876985aa1071ad5acc6dd", null ],
    [ "setDefaultStagingBufferlifetime", "class_ogre_1_1_g_l3_plus_vao_manager.html#a445b8e5486e061745af43d1831f60eb6", null ],
    [ "supportsArbBufferStorage", "class_ogre_1_1_g_l3_plus_vao_manager.html#aadc4d558e3a0893cb21661c05f74b463", null ],
    [ "supportsBaseInstance", "class_ogre_1_1_g_l3_plus_vao_manager.html#a7d9d6f2ebaa70d64fc171dd886ae218d", null ],
    [ "supportsIndirectBuffers", "class_ogre_1_1_g_l3_plus_vao_manager.html#afce1736c1c28af8657aaf863d366240f", null ],
    [ "supportsPersistentMapping", "class_ogre_1_1_g_l3_plus_vao_manager.html#a1945aa252817231abb52b12d4d5399a3", null ],
    [ "waitFor", "class_ogre_1_1_g_l3_plus_vao_manager.html#a7b9232ad54fd466bddf3d3983c50da76", null ],
    [ "waitForSpecificFrameToFinish", "class_ogre_1_1_g_l3_plus_vao_manager.html#a00cfc17aa6d593fa1c6ef272e2ee9ad9", null ],
    [ "waitForTailFrameToFinish", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad0260436ff6254a7f977f308148fa964", null ]
];

==> ogre-next-2.3.1-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_g_l3_plus_vao_manager.js <==
var class_ogre_1_1_g_l3_plus_vao_manager =
[
    [ "Block", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_block.html", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_block" ],
    [ "StrideChanger", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_stride_changer.html", "struct_ogre_1_1_g_l3_plus_vao_manager_1_1_stride_changer" ],
    [ "BlockVec", "class_ogre_1_1_g_l3_plus_vao_manager.html#acf63571a368c427ffdcfb1897ec5f041", null ],
    [ "MemoryStatsEntryVec", "class_ogre_1_1_g_l3_plus_vao_manager.html#a8a984ae987b00e95b35198131a4e9a6b", null ],
    [ "StrideChangerVec", "class_ogre_1_1_g_l3_plus_vao_manager.html#a79c5a9e410625780fcc610f3243be960", null ],
    [ "GL3PlusVaoManager", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4ceaf6e928e2079f263dab39e7d8d6a6", null ],
    [ "~GL3PlusVaoManager", "class_ogre_1_1_g_l3_plus_vao_manager.html#add095b8663546d8520f8cc9c0d92c90c", null ],
    [ "_beginFrame", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad255ed9aad893f120f6a29e172052ccd", null ],
    [ "_getDynamicBufferCurrentFrameNoWait", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4c2c223f495c035085ffa2b7323bce82", null ],
    [ "_notifyStagingBufferEnteredZeroRef", "class_ogre_1_1_g_l3_plus_vao_manager.html#a374058250675bac30bfb5b03c26b5eb7", null ],
    [ "_notifyStagingBufferLeftZeroRef", "class_ogre_1_1_g_l3_plus_vao_manager.html#ace2545e4ce03ff536e3d505e4669cc91", null ],
    [ "_update", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6a803fbce3bc62ad1bc5a0632bf69da7", null ],
    [ "bindDrawId", "class_ogre_1_1_g_l3_plus_vao_manager.html#ae7f85d710473526ee0985c4def94dcb5", null ],
    [ "calculateVertexSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#a222d4e40df5eb53ab0b050e37aca7b89", null ],
    [ "cleanupEmptyPools", "class_ogre_1_1_g_l3_plus_vao_manager.html#acfe2479c58ace6ff748d17cc0f65091d", null ],
    [ "createAsyncTicket", "class_ogre_1_1_g_l3_plus_vao_manager.html#a530db71d0308ab9ad62b1243be3196ff", null ],
    [ "createConstBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad918478b8b2fe87bd0cf5a0d800f9ca8", null ],
    [ "createIndexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#aaee81b43cbfe73850b5f48e0b3b04b2d", null ],
    [ "createIndirectBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a62af7df3a3d8cbe692a621741aa12e5c", null ],
    [ "createReadOnlyBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#af7c18af1342b5ae1a15d55838b667935", null ],
    [ "createStagingBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a7df3f4b01e5234a10c92b4d6026a62bc", null ],
    [ "createStagingTexture", "class_ogre_1_1_g_l3_plus_vao_manager.html#a9d7b3b0cab487f7cc1d44426f276c370", null ],
    [ "createTexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a9746fd2364a65422ca7beafef42ad82b", null ],
    [ "createUavBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a0937a414f9da637fb8878e10db724bba", null ],
    [ "createVertexArrayObject", "class_ogre_1_1_g_l3_plus_vao_manager.html#a21be4e3d6b7ad0490c59eb9db1cdcdf7", null ],
    [ "createVertexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#aefabb42c2a1a8f2d71af28ffaa91ba91", null ],
    [ "deleteStagingBuffers", "class_ogre_1_1_g_l3_plus_vao_manager.html#a204c8055903cea82fe38e6a9fbc62f6d", null ],
    [ "destroyConstBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a51f5147151805c3d294ae200683d76bb", null ],
    [ "destroyIndexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a04c53b84b4c6ba27fdcbf57a08d4b044", null ],
    [ "destroyIndirectBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4e7e88128e2496523ab0ca8e35634879", null ],
    [ "destroyReadOnlyBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a703bff2ff022184c4f40da6ecb9a19ee", null ],
    [ "destroyStagingTexture", "class_ogre_1_1_g_l3_plus_vao_manager.html#aa79c19ee474881cbf8f49600395c27ca", null ],
    [ "destroyTexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6241229a8f3c895dcd49e7d0e8dfe545", null ],
    [ "destroyUavBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a0f235ad527a20a7c20b9daae8dc18ff7", null ],
    [ "destroyVertexArrayObject", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4d56b87f51c489bdc2df07d1ce040512", null ],
    [ "destroyVertexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a1dce3c8cb8c7d08ff77e6c4776fed1f4", null ],
    [ "getAttributeIndexFor", "class_ogre_1_1_g_l3_plus_vao_manager.html#a2cdfac5014aab294b0c75ae452919bbd", null ],
    [ "getConstBufferAlignment", "class_ogre_1_1_g_l3_plus_vao_manager.html#a4a00e866aebffe5114767ce1fc81bea8", null ],
    [ "getConstBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6613f84365a386b9a50fed61a96cfc7a", null ],
    [ "getDefaultStagingBufferLifetime", "class_ogre_1_1_g_l3_plus_vao_manager.html#adb22409286339939dc6d49e44a8f3683", null ],
    [ "getDefaultStagingBufferUnfencedTime", "class_ogre_1_1_g_l3_plus_vao_manager.html#a5388b5890025a724a42f4469363bb267", null ],
    [ "getDynamicBufferMultiplier", "class_ogre_1_1_g_l3_plus_vao_manager.html#a9b609165fb053afe550711546254e230", null ],
    [ "getFrameCount", "class_ogre_1_1_g_l3_plus_vao_manager.html#ab528ecee92f02772be5dc8329c0e1e1b", null ],
    [ "getMaxVertexAttribs", "class_ogre_1_1_g_l3_plus_vao_manager.html#a5140b54e5640aa8b8b931a6c14d1e4c2", null ],
    [ "getMemoryStats", "class_ogre_1_1_g_l3_plus_vao_manager.html#a0c941ddbd14acb71c749d7a752e38ccc", null ],
    [ "getReadOnlyBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#ae8ea50dfdfc83e13bae02da290647884", null ],
    [ "getStagingBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a2f966c0b38fc30347f429aa85029107a", null ],
    [ "getTexBufferAlignment", "class_ogre_1_1_g_l3_plus_vao_manager.html#a6c4856f0420c296824372ce64825cbfd", null ],
    [ "getTexBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#a2d0feae113e7a1003d76b3640c51d243", null ],
    [ "getTimer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a8e2ce8d89d24f7cd169177f588a6a4d1", null ],
    [ "getUavBufferAlignment", "class_ogre_1_1_g_l3_plus_vao_manager.html#a50170e8b31bd91edd07b36c3fb6678f7", null ],
    [ "getUavBufferMaxSize", "class_ogre_1_1_g_l3_plus_vao_manager.html#ae94298022c4ca57ca88a9440c223af4c", null ],
    [ "isFrameFinished", "class_ogre_1_1_g_l3_plus_vao_manager.html#a82ef161fc8e37d2217cd10c849005a16", null ],
    [ "mergeContiguousBlocks", "class_ogre_1_1_g_l3_plus_vao_manager.html#addb5d4187c15479363e1cf47a7b21844", null ],
    [ "operator delete", "class_ogre_1_1_g_l3_plus_vao_manager.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_g_l3_plus_vao_manager.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_g_l3_plus_vao_manager.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_g_l3_plus_vao_manager.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_g_l3_plus_vao_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_g_l3_plus_vao_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "readOnlyIsTexBuffer", "class_ogre_1_1_g_l3_plus_vao_manager.html#a62bef9b46aa4eb7100cab724b4b0811a", null ],
    [ "setDefaultStagingBufferlifetime", "class_ogre_1_1_g_l3_plus_vao_manager.html#a445b8e5486e061745af43d1831f60eb6", null ],
    [ "supportsArbBufferStorage", "class_ogre_1_1_g_l3_plus_vao_manager.html#aadc4d558e3a0893cb21661c05f74b463", null ],
    [ "supportsBaseInstance", "class_ogre_1_1_g_l3_plus_vao_manager.html#a7d9d6f2ebaa70d64fc171dd886ae218d", null ],
    [ "supportsIndirectBuffers", "class_ogre_1_1_g_l3_plus_vao_manager.html#afce1736c1c28af8657aaf863d366240f", null ],
    [ "supportsPersistentMapping", "class_ogre_1_1_g_l3_plus_vao_manager.html#a1945aa252817231abb52b12d4d5399a3", null ],
    [ "waitFor", "class_ogre_1_1_g_l3_plus_vao_manager.html#a7b9232ad54fd466bddf3d3983c50da76", null ],
    [ "waitForSpecificFrameToFinish", "class_ogre_1_1_g_l3_plus_vao_manager.html#a00cfc17aa6d593fa1c6ef272e2ee9ad9", null ],
    [ "waitForTailFrameToFinish", "class_ogre_1_1_g_l3_plus_vao_manager.html#ad0260436ff6254a7f977f308148fa964", null ]
];
